/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.tinydb;

/**
 * 数据库相关的操作<br>
 * 注意，不能构建成环形嵌套，否则会形成死循环
 * 
 * @author luoguo
 * 
 * @param <BeanType>
 * @param <KeyType>
 */
public interface DBOperator<BeanType,KeyType> extends DbOperatorSingle<BeanType,KeyType>,
		DbOperatorBatch<BeanType,KeyType>, DbOperatorBase {
	/**
	 * 添加子处理器，通过子处理器可以进行级联处理<br>
	 * 比如：角色与用户一对多关系，且用户表中存在字段role_id<br>
	 * 当给角色添加了子处理器"用户处理器"时，则在获取角色的时候，会添加指定角色下的用户列表到当前下面对象,Key为子对象名字+List，类型为List
	 * <Bean><br>
	 * 比如：role操作下有tiny_user，则在role
	 * Bean对象中，有个叫tinyUserList的Key，对应的Value是List<Bean>格式。
	 * 
	 * @param dbOperation
	 */
	void addSubDbOperator(DBOperator<BeanType,KeyType> dbOperation, String foreignKey);
	void addSubDbOperator(String subType, String foreignKey);

}
